@@ -308,7 +308,7 @@ GDALPansharpenOperation::Initialize(const GDALPansharpenOptions *psOptionsIn)
             CPLError(CE_Failure, CPLE_AppDefined,
                      "Dimensions of input spectral band %d different from "
                      "first spectral band",
-                     i);
+                     i + 1);
             return CE_Failure;
         }
 
@@ -318,8 +318,8 @@ GDALPansharpenOperation::Initialize(const GDALPansharpenOptions *psOptionsIn)
         {
             CPLError(CE_Failure, CPLE_AppDefined,
                      "Cannot retrieve dataset associated with "
-                     "ahInputSpectralBands[%i]",
-                     i);
+                     "input spectral band %d",
+                     i + 1);
             return CE_Failure;
         }
         // Make sure that the band is really a first level child of the owning dataset
@@ -335,16 +335,16 @@ GDALPansharpenOperation::Initialize(const GDALPansharpenOptions *psOptionsIn)
         {
             CPLError(
                 CE_Failure, CPLE_AppDefined,
-                "ahInputSpectralBands[%d] band has no associated geotransform",
-                i);
+                "input spectral band %d band has no associated geotransform",
+                i + 1);
             return CE_Failure;
         }
         if (adfMSGT != adfRefMSGT)
         {
             CPLError(CE_Failure, CPLE_AppDefined,
-                     "ahInputSpectralBands[%d] band has a different "
-                     "geotransform than ahInputSpectralBands[0]",
-                     i);
+                     "input spectral band %d has a different "
+                     "geotransform than the first spectral band",
+                     i + 1);
             return CE_Failure;
         }
 
